<?php
namespace App\Model;

use Illuminate\Database\Eloquent\Model;
use DB;
use Carbon\Carbon;

class QuizModel extends Model
{
    protected $connection = 'mysql2';

    public function __construct()
    {
    }
   
    public function getSessionID($email)
    {
        // $email = 'testing1@p80w.com';
        // $email = 'tester@p80w.com';
        $sessionID = [];
        if (!empty($email)) {
            $sessionID = DB::connection('mysql2')->select('
                select 
                    qu.session_id
                from 
                    quiz_user as qu
                join 
                    users as u
                on 
                    qu.user_id = u.id
                where u.user_email = ?', [$email]);
        }

        return $sessionID;
    }

    public function getQuizDetails($sessionIDs)
    {
        $sessionId = '"' . implode('", "', explode(',', $sessionIDs)) . '"';
        $quizDetails = DB::connection('mysql2')->select('
        select
            ur.session_id,
            qu.created_at,
            qm.question,
            case when rec.session_id is null then "No" else "Yes" end as isrecommendation,
            IFNULL(qr.response,ur.response_text) as response,
            ur.created_at as completion_time,
            rec.first_name,
            rec.email
        from
            user_responses as ur
        join
            question_master as qm
        on
            qm.id = ur.qn_id
        
        left join
            quiz_user as qu
        on
            qu.session_id = ur.session_id
        
        left join
            question_responses as qr
        on
            ur.response_id = qr.id
        left outer join 
			recommendations as rec
		on 
			ur.session_id = rec.session_id
        where
            ur.session_id in (' . $sessionId . ')');
            
        $quizDetails = $this->formatQuizDetails($quizDetails);

        return $quizDetails;
    }

    public function formatQuizDetails($quizDetails)
    {
        $quizData = [];
        if (!empty($quizDetails)) {
            foreach ($quizDetails as $data)
            {
                $data->created_at = $this->getQuizdate($data->created_at);
                // echo"<pre>";print_r($data);die;
                if (!isset($quizData[$data->session_id])) {
                    $quizData[$data->session_id][] = $data;
                }
                else {
                    $quizData[$data->session_id][] = $data;
                }
            }
        }
        
        return $quizData;
    }
    
    public function getQuizDate($date){
        
        if(!empty($date)){
            $updatedTime = new Carbon($date, 'America/Los_Angeles');
            return $updatedTime->format('c');
        }
        
    }

    public function getRecommendation($sessionID)
    {
        if (!empty($sessionID)) {
            $quizRecommendations = DB::connection('mysql2')->select('
                select
                    recommendation
                from 
                    recommendations    
                where
                    session_id = ?', [$sessionID]);
            
            if (!empty($quizRecommendations)) {
                return $quizRecommendations[0]->recommendation;
            }
        }

        return null;
    }

    public function getQuizDetailsByEmail($email)
    {
        $quizResult = [];
        $quizDetails = DB::connection('mysql2')->select('
            select
                qu.session_id,
                qu.created_at,
                u.user_email,
                case when rec.session_id is null then "No" else "Yes" end as isrecommendation
            from
                quiz_user as qu
            
            left join
                users as u
            on
                u.id = qu.user_id
            
            left outer join 
                (select distinct (session_id) from recommendations) as rec
            on 
                qu.session_id = rec.session_id
            where
                u.user_email in ('. $email . ')');   //  qu.status = 1 and 

        if (!empty($quizDetails)) {
            
            foreach ($quizDetails as $quizData) {
                
                //echo '<pre>'; print_r($quizData);die;
                
                $quizData->created_at = $this->getQuizdate($quizData->created_at);
                
                if (!isset($quizResult[$quizData->user_email])) {
                    $quizResult[$quizData->user_email][] = (array)$quizData;
                } else {
                    $quizResult[$quizData->user_email][] = (array)$quizData;
                }
            }
        }
        return $quizResult;
    }

    public function getCustomerNamesByEmail($email)
    {
        $result = [];
        $quizDetails = DB::connection('mysql2')->select('
            select
                qu.session_id,
                u.user_email,
                ur.response_text as name
            from
                quiz_user as qu
            
            left join
                users as u
            on
                u.id = qu.user_id

            left join
                user_responses as ur
            on
                ur.session_id = qu.session_id
            where
            ur.qn_id = 2 and u.user_email in ('. $email . ')');

        if (!empty($quizDetails)) {
            foreach ($quizDetails as $quizData) {
                $result[$quizData->user_email] = $quizData->name;
            }
        }

        return $result;
    }

    public function getSessionIds($email)
    {
        $sessionIds = '';
        $quizDetails = DB::connection('mysql2')->select('
            select
                qu.session_id
            from
                quiz_user as qu
            
            left join
                users as u
            on
                u.id = qu.user_id
            
            where
                u.user_email = ?', [$email]);   // and qu.status = 1 
        if (!empty($quizDetails)) {
            foreach ($quizDetails as $quizDetail) {
                $sessionIds .= $quizDetail->session_id.",";
            }
        }
        return rtrim($sessionIds, ",");
    }
    
    public function getCustomFields($sessionID){
        if (!empty($sessionID)) {
            $customFields = DB::connection('mysql2')->select('
                select
                    response_time
                from
                    recommendations
                where
                    session_id = ?', [$sessionID]);

            if (!empty($customFields)) {
                $customDetails = [];
                $customDetails['responseTime'] = round($customFields[0]->response_time,5);
                return $customDetails;
            }
        }

        return null;
    }
}
